@@ -5,6 +5,7 @@ from pathlib import Path
 import threading
 import time
 from typing import Union, Optional, Callable, Any, List
+from datetime import datetime
 
 from PyQt5.QtWidgets import QApplication
 from PyQt5.QtCore import QTimer
@@ -90,6 +91,7 @@ class App(QApplication):
         self.stop_threads_event = threading.Event()
         self._data = {}
         self.zmq_subscribers = {}
+        self.birth_time = datetime.utcnow().timestamp()
 
         # publisher that announces commands for instruments
         if ipaddress is None:
@@ -447,7 +449,6 @@ class App(QApplication):
         if value is None:
             logger.info(f"Hook blocked setting of parameter '{instrument}-{parameter}'")
             return
-
         self._data[instrument][parameter]["set_value"] = value
         self.zmq_publisher.send_string(
             f"{instrument} {priority} set {parameter} {value}"
@@ -668,7 +669,9 @@ class App(QApplication):
             )
 
     @ensure_instrument_exists
-    def load_settings_hook(self, instrument: str, filename: Union[str, Path]) -> None:
+    def load_settings_hook(
+        self, instrument: str, filename: Union[str, Path], skip_hooks: bool = True
+    ) -> None:
         def hook_function(value):
             """Reads a JSON file to overwrite instrument's settings.
 
@@ -694,7 +697,6 @@ class App(QApplication):
             except:
                 logger.error(f"Failed to read file '{filename}'.", exc_info=True)
                 return value
-
             # Try to set instrument settings
             if instrument not in self._data:
                 logger.warning(
@@ -709,10 +711,10 @@ class App(QApplication):
                     return value
                 set_value = all_settings[parameter]
                 self.set_instrument_parameter(
-                    instrument, parameter, set_value, skip_hooks=True
+                    instrument, parameter, set_value, skip_hooks=skip_hooks
                 )
 
-                return value
+            return value
 
         return hook_function
 
@@ -732,5 +734,5 @@ class App(QApplication):
             instrument,
             "ONLINE",
             "post_read_hooks",
-            self.load_settings_hook(instrument, filename),
+            self.load_settings_hook(instrument, filename, skip_hooks=False),
         )
