@@ -388,6 +388,7 @@ class HCOnOffButton(HCMixin, QPushButton):
         text_unchecked: str = "Off",
         icon_checked: str = "button-power-on.svg",
         icon_unchecked: str = "button-power-off.svg",
+        show_set_text: bool = False,
     ):
         super().__init__(
             app=app,
@@ -399,12 +400,14 @@ class HCOnOffButton(HCMixin, QPushButton):
         )
 
         self.show_icon = show_icon
+        self.show_text = show_text
+        self.show_set_text = show_set_text
+
         if self.show_icon:
             self.icon_checked = load_icon(icon_checked)
             self.icon_unchecked = load_icon(icon_unchecked)
             self.icon_unknown = load_icon("button-power-unknown.svg")
 
-        self.show_text = show_text
         if self.show_text:
             self.text_checked = text_checked
             self.text_unchecked = text_unchecked
@@ -413,9 +416,9 @@ class HCOnOffButton(HCMixin, QPushButton):
         self.setCheckable(False)
 
         # set default to unkown state
-        if show_icon:
+        if self.show_icon:
             self.setIcon(self.icon_unknown)
-        if show_text:
+        if self.show_text:
             self.setText("unkown")
 
     def is_true(self, value: Union[bool, str]) -> bool:
@@ -427,18 +430,18 @@ class HCOnOffButton(HCMixin, QPushButton):
                 return True
         return False
 
-    def set_state(self, value):
+    def set_btn_state(self, value):
         """Change the icon and/or text display."""
         if self.show_icon:
-            if value == "True":
+            if self.is_true(value):
                 self.setIcon(self.icon_checked)
-            elif value == "False":
+            elif not self.is_true(value):
                 self.setIcon(self.icon_unchecked)
 
         if self.show_text:
-            if value == "True":
+            if self.is_true(value):
                 self.setText(self.text_checked)
-            elif value == "False":
+            elif not self.is_true(value):
                 self.setText(self.text_unchecked)
 
     def value_change(self) -> None:
@@ -446,9 +449,12 @@ class HCOnOffButton(HCMixin, QPushButton):
         value = self.app.get_instrument_parameter(self.instrument, self.parameter)
         new_value = not (value == "True")
         self.app.set_instrument_parameter(self.instrument, self.parameter, new_value)
+        if self.show_set_text:
+            self.set_btn_state(new_value)
 
     def widget_update(self, value):
-        self.set_state(value)
+        if not self.show_set_text:
+            self.set_btn_state(value)
 
 
 class HCOnOffIndicator(HCMixin, QLabel):
